package com.link.core.util;

import com.alibaba.fastjson.JSONObject;
import com.github.qcloudsms.SmsMultiSender;
import com.github.qcloudsms.SmsMultiSenderResult;
import com.github.qcloudsms.SmsMultiSenderResult.Detail;
import com.link.base.sms.model.SendResult;
import com.link.base.sms.model.SmsAccntLine;
import com.link.base.sms.model.SmsSend;
import com.link.base.sms.model.Temparameter;
import com.link.base.sms.model.Template;
import com.link.core.util.HttpUtils;
import com.link.core.util.JsonUtil;
import com.link.core.util.PropertyUtil;
import com.link.core.util.RedisUtil;
import com.link.core.util.StringUtils;
import com.link.core.util.redisclient.LinkRedisClient;
import com.qcloud.sms.SmsSingleSender;
import com.qcloud.sms.SmsSingleSenderResult;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import org.apache.http.HttpResponse;
import org.apache.http.util.EntityUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class SendSmsUtil {

   private static final Logger logger = LogManager.getLogger(SendSmsUtil.class);
   public static final String APPKEY = PropertyUtil.getCommonProperty("tencentAppKey");
   public static final int APPID = Integer.parseInt(PropertyUtil.getCommonProperty("tencentAppId"));
   public static final String NAtIONCODE = "86";
   public static final int allPhoneNumSendTimesLimitOneDay = 100000;
   public static final int singlePhoneNumSendTimesLimitOneDay = 100;
   public static final String host = "http://sms.market.alicloudapi.com";
   public static final String path = "/singleSendSms";
   public static final String method = "GET";
   private static final String appCode = PropertyUtil.getCommonProperty("AppCode");
   public static final String signName = "Link产品";
   public static final String redisKeyForMsgTotalPrefix = "MsgCounter#";
   public static final String redisFieldTotal = "Total";


   public static void main(String[] args) {
      LinkedHashMap param = new LinkedHashMap();
      param.put("no", "224512");
      System.out.println(sendMsg("", "SMS_50065081", param, "VertificationCode") + APPKEY + APPID);
   }

   private static String send(String phoneNumber, String templateCode, Map param) {
      HashMap headers = new HashMap();
      headers.put("Authorization", appCode);
      HashMap querys = new HashMap();
      querys.put("ParamString", JSONObject.toJSONString(param));
      querys.put("RecNum", phoneNumber);
      querys.put("SignName", "Link产品");
      querys.put("TemplateCode", templateCode);

      String str;
      try {
         HttpResponse e = HttpUtils.doGet("http://sms.market.alicloudapi.com", "/singleSendSms", "GET", headers, querys);
         str = EntityUtils.toString(e.getEntity());
         logger.debug("短信[" + templateCode + "] 发送 [" + phoneNumber + "]: " + str);
         return str;
      } catch (Exception var7) {
         logger.error("MsgUtil捕获异常: ", var7);
         str = "{\"success\":false,\"result\":\"" + var7.getMessage() + "\"}";
         return str;
      }
   }

   public static String sendMsg(String phoneNumber, String templateCode, LinkedHashMap param, String msgType) {
      String beforeSendResult = beforeSend(phoneNumber);
      if(beforeSendResult != null) {
         return beforeSendResult;
      } else if("Ali".equals(PropertyUtil.getCommonProperty("SMS_PLATFORM"))) {
         String e1 = send(phoneNumber, templateCode, param);
         if(e1 != null && e1.contains("\"success\":true")) {
            System.out.println("true");
            afterSend(phoneNumber);
            if(!StringUtils.isBlank(msgType)) {
               upsertMsgType(phoneNumber, templateCode, param, msgType);
            }

            return e1;
         } else {
            return e1 != null?e1:"{\"success\":false,\"result\":null}";
         }
      } else {
         try {
            int e = Integer.valueOf(templateCode).intValue();
            ArrayList paramList = new ArrayList(param.values());
            SmsSingleSender singleSender = new SmsSingleSender(APPID, APPKEY);
            SmsSingleSenderResult singleSenderResult = singleSender.sendWithParam("86", phoneNumber, e, paramList, "", "", "");
            if(singleSenderResult.result == 0) {
               afterSend(phoneNumber);
               if(!StringUtils.isBlank(msgType)) {
                  upsertMsgType(phoneNumber, templateCode, param, msgType);
               }

               logger.debug("短信[" + templateCode + "]发送[ " + phoneNumber + " ] 成功");
               return "{\"success\":true}";
            } else {
               logger.error(singleSenderResult);
               return "{\"success\":false,\"result\":null}";
            }
         } catch (Exception var9) {
            logger.error("短信发送[ " + phoneNumber + " ]错误: " + var9.getMessage());
            return "{\"success\":false,\"result\":" + var9.getMessage() + "}";
         }
      }
   }

   public static Map sendMsg2(String phoneNumber, String templateCode, LinkedHashMap param, String msgType) {
      String resultStr = sendMsg(phoneNumber, templateCode, param, msgType);
      return (Map)JsonUtil.fromJsonStringToT(resultStr, Map.class);
   }

   private static void upsertMsgType(String phoneNumber, String templateCode, Map param, String msgType) {
      LinkRedisClient jedis = null;

      try {
         jedis = RedisUtil.getJedis();
         String redisKey = msgType + phoneNumber;
         jedis.hmset(redisKey, param);
         jedis.hset(redisKey, "Time", String.valueOf(System.currentTimeMillis()));
         jedis.hset(redisKey, "TemplateCode", templateCode);
         jedis.expire(redisKey, Integer.valueOf(86400));
      } finally {
         RedisUtil.returnResource(jedis);
      }

   }

   private static String beforeSend(String phoneNumber) {
      LinkRedisClient jedis = null;

      String var7;
      try {
         jedis = RedisUtil.getJedis();
         String allTotalStr = jedis.hget("MsgCounter#", "Total");
         String totalStr;
         String total1;
         if(allTotalStr != null) {
            int redisKey = Integer.valueOf(allTotalStr).intValue();
            if(redisKey >= 100000) {
               totalStr = "您好，很抱歉当前系统发送验证码次数已超出限制，今天暂时内无法再发送信息！";
               total1 = "{\"success\":false,\"result\":\"" + totalStr + "\"}";
               return total1;
            }
         }

         String redisKey1 = "MsgCounter#" + phoneNumber;
         totalStr = jedis.hget(redisKey1, "Total");
         if(totalStr == null) {
            total1 = null;
            return total1;
         }

         int total = Integer.valueOf(totalStr).intValue();
         if(total < 100) {
            return null;
         }

         String errorMsg = "该号码【" + phoneNumber + "】今天发送" + total + "次，请勿频繁发送";
         var7 = "{\"success\":false,\"result\":\"" + errorMsg + "\"}";
      } finally {
         RedisUtil.returnResource(jedis);
      }

      return var7;
   }

   private static void afterSend(String phoneNumber) {
      LinkRedisClient jedis = null;

      try {
         jedis = RedisUtil.getJedis();
         int leftDay = (int)((getThisDayEndTime() - System.currentTimeMillis()) / 1000L);
         String allTotalStr = jedis.hget("MsgCounter#", "Total");
         if(allTotalStr == null) {
            jedis.hset("MsgCounter#", "Total", "1");
            jedis.expire("MsgCounter#", Integer.valueOf(leftDay));
         } else {
            jedis.hset("MsgCounter#", "Total", String.valueOf(Integer.valueOf(allTotalStr).intValue() + 1));
            jedis.expire("MsgCounter#", Integer.valueOf(leftDay));
         }

         String redisKey = "MsgCounter#" + phoneNumber;
         String totalStr = jedis.hget(redisKey, "Total");
         if(totalStr != null) {
            jedis.hset(redisKey, "Total", String.valueOf(Integer.valueOf(totalStr).intValue() + 1));
         } else {
            jedis.hset(redisKey, "Total", "1");
            jedis.expire(redisKey, Integer.valueOf(leftDay));
         }
      } finally {
         RedisUtil.returnResource(jedis);
      }

   }

   public static long getThisDayStartTime() {
      Calendar calendar = Calendar.getInstance();
      calendar.setTime(new Date());
      calendar.set(11, 0);
      calendar.set(12, 0);
      calendar.set(13, 0);
      Date start = calendar.getTime();
      return start.getTime();
   }

   public static long getThisDayEndTime() {
      Calendar calendar = Calendar.getInstance();
      calendar.setTime(new Date());
      calendar.set(11, 23);
      calendar.set(12, 59);
      calendar.set(13, 59);
      Date end = calendar.getTime();
      return end.getTime();
   }

   public static List sendSms(SmsSend SmsSend) {
      SendResult sendResult = null;
      ArrayList resus = new ArrayList();
      ArrayList params = new ArrayList();
      Template tem = SmsSend.getTemplate();
      Temparameter te = SmsSend.getTemparameter();
      if(!StringUtils.isNull(te.getParameter1())) {
         params.add(te.getParameter1());
         if(!StringUtils.isNull(te.getParameter2())) {
            params.add(te.getParameter2());
            if(!StringUtils.isNull(te.getParameter3())) {
               params.add(te.getParameter3());
               if(!StringUtils.isNull(te.getParameter4())) {
                  params.add(te.getParameter4());
                  if(!StringUtils.isNull(te.getParameter5())) {
                     params.add(te.getParameter5());
                     if(!StringUtils.isNull(te.getParameter6())) {
                        params.add(te.getParameter6());
                        if(!StringUtils.isNull(te.getParameter7())) {
                           params.add(te.getParameter7());
                           if(!StringUtils.isNull(te.getParameter8())) {
                              params.add(te.getParameter8());
                              if(!StringUtils.isNull(te.getParameter9())) {
                                 params.add(te.getParameter9());
                                 if(!StringUtils.isNull(te.getParameter10())) {
                                    params.add(te.getParameter10());
                                 }
                              }
                           }
                        }
                     }
                  }
               }
            }
         }
      }

      List account = SmsSend.getSmsAccntLineList();
      ArrayList phoneNumbers = new ArrayList();
      Iterator sender = account.iterator();

      while(sender.hasNext()) {
         SmsAccntLine e = (SmsAccntLine)sender.next();
         phoneNumbers.add(e.getMobilePhone1());
      }

      Iterator var10;
      if(account.size() > 1) {
         try {
            SmsMultiSender sender1 = new SmsMultiSender(APPID, APPKEY);
            SmsMultiSenderResult e1 = sender1.sendWithParam("86", phoneNumbers, tem.getTemplID().intValue(), params, SmsSend.getSigText(), SmsSend.getExtend(), SmsSend.getExt());
            var10 = e1.details.iterator();

            while(var10.hasNext()) {
               Detail C = (Detail)var10.next();
               Iterator var12 = account.iterator();

               while(var12.hasNext()) {
                  SmsAccntLine Account = (SmsAccntLine)var12.next();
                  if(StringUtils.equals(C.phoneNumber, Account.getMobilePhone1())) {
                     sendResult = new SendResult(Integer.valueOf(C.result), C.errMsg, Integer.valueOf(C.fee), C.phoneNumber, C.nationCode, C.sid, SmsSend.getId(), e1.ext, Account.getId(), Account, getRequestStatus(C.result));
                     resus.add(sendResult);
                  }
               }
            }
         } catch (Exception var15) {
            logger.error("SendSmsUtil捕获异常: ", var15);
         }
      } else {
         try {
            com.github.qcloudsms.SmsSingleSender sender2 = new com.github.qcloudsms.SmsSingleSender(APPID, APPKEY);
            com.github.qcloudsms.SmsSingleSenderResult e2 = sender2.sendWithParam("86", (String)phoneNumbers.get(0), tem.getTemplID().intValue(), params, SmsSend.getSigText(), SmsSend.getExtend(), SmsSend.getExt());
            var10 = account.iterator();

            while(var10.hasNext()) {
               SmsAccntLine C1 = (SmsAccntLine)var10.next();
               sendResult = new SendResult(Integer.valueOf(e2.result), e2.errMsg, Integer.valueOf(e2.fee), (String)phoneNumbers.get(0), "86", e2.sid, SmsSend.getId(), e2.ext, C1.getId(), C1, getRequestStatus(e2.result));
               resus.add(sendResult);
            }
         } catch (Exception var14) {
            logger.error("SendSmsUtil捕获异常: ", var14);
         }
      }

      return resus;
   }

   public static String getRequestStatus(int idex) {
      String requestStatus;
      if(0 == idex) {
         requestStatus = "SUCCESS";
      } else {
         requestStatus = "FAIL";
      }

      return requestStatus;
   }

}
